summaryrefslogtreecommitdiff
path: root/cesar
diff options
context:
space:
mode:
authorschodet2008-08-14 09:25:47 +0000
committerschodet2008-08-14 09:25:47 +0000
commit2f872a16f62244449337582d3b52d33b78ebb3ba (patch)
treeffc9bcb7e7cf5e37357821e89d90e77cff701074 /cesar
parent74a40510e322e5a83a874a04cea557b02fc16e5a (diff)
* cp2/fsm, cp2/sta/action:
- renamed associated and unassociated events to joined and left. git-svn-id: svn+ssh://pessac/svn/cesar/trunk@2726 017c9cb6-072f-447c-8318-d5b54f68fe89
Diffstat (limited to 'cesar')
-rw-r--r--cesar/cp2/fsm/src/fsm/cp.fsm14
-rw-r--r--cesar/cp2/sta/action/assoc.h9
-rw-r--r--cesar/cp2/sta/action/doc/drv.sdl2
-rw-r--r--cesar/cp2/sta/action/doc/poweron.sdl10
-rw-r--r--cesar/cp2/sta/action/drv.h4
-rw-r--r--cesar/cp2/sta/action/poweron.h8
-rw-r--r--cesar/cp2/sta/action/src/drv.c2
-rw-r--r--cesar/cp2/sta/action/src/poweron.c4
-rw-r--r--cesar/cp2/sta/action/test/utest/inc/scenario_defs.h12
-rw-r--r--cesar/cp2/sta/action/test/utest/src/poweron.c4
-rw-r--r--cesar/cp2/sta/action/test/utest/src/scenario_actions.c6
11 files changed, 42 insertions, 33 deletions
diff --git a/cesar/cp2/fsm/src/fsm/cp.fsm b/cesar/cp2/fsm/src/fsm/cp.fsm
index 7d23a6cfd7..46dd7f238f 100644
--- a/cesar/cp2/fsm/src/fsm/cp.fsm
+++ b/cesar/cp2/fsm/src/fsm/cp.fsm
@@ -32,6 +32,8 @@ Events:
CM_SET_KEY_REQ
CC_LEAVE_IND
CC_LEAVE_CNF
+ joined
+ left
DRV_STA_SET_MAC_ADDR_REQ
DRV_STA_SET_CCO_PREF_REQ
@@ -46,7 +48,6 @@ Events:
DRV_STA_SET_TONEMASK_REQ
DRV_STA_MAC_START_REQ
DRV_STA_MAC_STOP_REQ
- unassociated
btt_timeout
ustt_timeout
@@ -56,7 +57,6 @@ Events:
association_request
net_list_empty
usta_ind
- associated
BEACON_NOT_RECEIVED
snid_conflict
@@ -124,7 +124,7 @@ STARTED:
send DRV_STA_MAC_STOP.CNF
STOPPING:
- unassociated -> STOPPED [cp_sta_action_drv__stopping__unassoc]
+ left -> STOPPED [cp_sta_action_drv__stopping__left]
send DRV_STA_MAC_STOP.CNF
@@ -147,13 +147,13 @@ USTA:
usta_ind: else -> .
POWERON_JOINING:
- unassociated -> POWERON [cp_sta_action_poweron__poweron_joining__unassociated]
+ left -> POWERON [cp_sta_action_poweron__poweron_joining__left]
USTA_JOINING:
- unassociated -> USTA [cp_sta_action_poweron__usta_joining__unassociated]
+ left -> USTA [cp_sta_action_poweron__usta_joining__left]
POWERON_JOINING, USTA_JOINING:
- associated -> STA [NULL]
+ joined -> STA [NULL]
UCCO:
BEACON -> USTA [NULL]
@@ -164,7 +164,7 @@ STA:
clear missed beacon counter
BEACON_NOT_RECEIVED: avln failure -> POWERON [cp_sta_action_poweron__sta__beacon_not_received]
BEACON_NOT_RECEIVED: else -> .
- unassociated -> USTA [NULL]
+ left -> USTA [NULL]
CCO:
join_timeout: sta -> . [cp_sta_action_poweron__cco__join_timeout]
diff --git a/cesar/cp2/sta/action/assoc.h b/cesar/cp2/sta/action/assoc.h
index 7f59c3c507..4880fe88cc 100644
--- a/cesar/cp2/sta/action/assoc.h
+++ b/cesar/cp2/sta/action/assoc.h
@@ -99,6 +99,15 @@
* The "leave wait" state is there to give time to the data plane to send the
* MME. After a fixed timer, go back to unassociated state and cleanup the
* data plane from all AVLN related parameters.
+ *
+ * Events
+ * ------
+ *
+ * When the authenticated state is entered, the join event is triggered.
+ *
+ * When the unassociated state is entered, the left event is triggered. This
+ * event means that the station has left the AVLN or that the association
+ * request failed.
*/
#include "cp2/sta/mgr/net.h"
diff --git a/cesar/cp2/sta/action/doc/drv.sdl b/cesar/cp2/sta/action/doc/drv.sdl
index 9e735519d8..d790a4e434 100644
--- a/cesar/cp2/sta/action/doc/drv.sdl
+++ b/cesar/cp2/sta/action/doc/drv.sdl
@@ -1,6 +1,6 @@
(stopped) -DRV_STA_MAC_START.REQ(1)-> (started)
... -DRV_STA_MAC_STOP.REQ-> <unassociated?> -y(2)-> (stopped)
<unassociated?> -n-> (stopping)
-(stopping) -unassociated(2)-> (stopped)
+(stopping) -left(2)-> (stopped)
(stopped) -DRV_STA_SET_*.REQ(3)-> (stopped)
diff --git a/cesar/cp2/sta/action/doc/poweron.sdl b/cesar/cp2/sta/action/doc/poweron.sdl
index c9f8bd17c2..a10fd08286 100644
--- a/cesar/cp2/sta/action/doc/poweron.sdl
+++ b/cesar/cp2/sta/action/doc/poweron.sdl
@@ -6,8 +6,8 @@ poweron:
<b:avln?> -n-> (ucco)
(poweron) -beacon-> <:NID match?> -n(2)-> (poweron)
<:NID match?> -y-> (poweron joining)
-(poweron joining) -unassociated(2)-> (poweron)
-(poweron joining) -associated-> (sta)
+(poweron joining) -left(2)-> (poweron)
+(poweron joining) -joined-> (sta)
usta:
(usta) -ustt timeout-> <:avln?> -n-> (usta)
@@ -17,15 +17,15 @@ usta:
(usta) -usta ind-> <:NID match\n& CCo?> -y-> (cco)
<:NID match\n& CCo?> -n-> (usta)
(usta) -net list empty-> (ucco)
-(usta joining) -unassociated(2)-> (usta)
-(usta joining) -associated-> (sta)
+(usta joining) -left(2)-> (usta)
+(usta joining) -joined-> (sta)
ucco:
(ucco) -beacon-> (usta)
(ucco) -association request-> (cco)
sta:
-(sta) -unassociated-> (usta)
+(sta) -left-> (usta)
(sta) -beacon(3)-> (sta)
(sta) -beacon not received-> <:avln failure?> -y-> (poweron)
<:avln failure?> -n-> (sta)
diff --git a/cesar/cp2/sta/action/poweron.h b/cesar/cp2/sta/action/poweron.h
index 5f9150541e..5484aea3ba 100644
--- a/cesar/cp2/sta/action/poweron.h
+++ b/cesar/cp2/sta/action/poweron.h
@@ -83,13 +83,13 @@ cp_sta_action_poweron__poweron__beacon (cp_t *ctx, cp_net_t *net,
cp_sta_t *sta);
/**
- * Handle POWERON_JOINING => UNASSOCIATED.
+ * Handle POWERON_JOINING => LEFT.
* \param ctx control plane context
*
* Select an AVLN to track and continue searching.
*/
void
-cp_sta_action_poweron__poweron_joining__unassociated (cp_t *ctx);
+cp_sta_action_poweron__poweron_joining__left (cp_t *ctx);
/**
* Handle USTA => USTT TIMEOUT.
@@ -128,13 +128,13 @@ cp_sta_action_poweron__usta__usta_ind (cp_t *ctx, cp_net_t *net,
cp_sta_t *sta);
/**
- * Handle USTA_JOINING => UNASSOCIATED.
+ * Handle USTA_JOINING => LEFT.
* \param ctx control plane context
*
* Select an AVLN to track and continue searching.
*/
void
-cp_sta_action_poweron__usta_joining__unassociated (cp_t *ctx);
+cp_sta_action_poweron__usta_joining__left (cp_t *ctx);
/**
* Handle entering STA.
diff --git a/cesar/cp2/sta/action/src/drv.c b/cesar/cp2/sta/action/src/drv.c
index 739a71c16f..a16174b9e9 100644
--- a/cesar/cp2/sta/action/src/drv.c
+++ b/cesar/cp2/sta/action/src/drv.c
@@ -180,7 +180,7 @@ cp_sta_action_drv__started__drv_sta_mac_stop_req (cp_t *ctx,
}
void
-cp_sta_action_drv__stopping__unassoc (cp_t *ctx)
+cp_sta_action_drv__stopping__left (cp_t *ctx)
{
}
diff --git a/cesar/cp2/sta/action/src/poweron.c b/cesar/cp2/sta/action/src/poweron.c
index ab3b33d721..9bcd40c21c 100644
--- a/cesar/cp2/sta/action/src/poweron.c
+++ b/cesar/cp2/sta/action/src/poweron.c
@@ -152,7 +152,7 @@ cp_sta_action_poweron__poweron__beacon (cp_t *ctx, cp_net_t *net,
}
void
-cp_sta_action_poweron__poweron_joining__unassociated (cp_t *ctx)
+cp_sta_action_poweron__poweron_joining__left (cp_t *ctx)
{
}
@@ -200,7 +200,7 @@ cp_sta_action_poweron__usta__usta_ind (cp_t *ctx, cp_net_t *net,
}
void
-cp_sta_action_poweron__usta_joining__unassociated (cp_t *ctx)
+cp_sta_action_poweron__usta_joining__left (cp_t *ctx)
{
}
diff --git a/cesar/cp2/sta/action/test/utest/inc/scenario_defs.h b/cesar/cp2/sta/action/test/utest/inc/scenario_defs.h
index e70dc52135..ae51f3ed15 100644
--- a/cesar/cp2/sta/action/test/utest/inc/scenario_defs.h
+++ b/cesar/cp2/sta/action/test/utest/inc/scenario_defs.h
@@ -58,7 +58,7 @@
drv__stopped__drv_sta_set_tonemask_req, \
drv__stopped__drv_sta_mac_start_req, \
drv__started__drv_sta_mac_stop_req, \
- drv__stopping__unassoc, \
+ drv__stopping__left, \
\
process_cc_set_tei_map_ind, \
process_cm_unassociated_sta_ind, \
@@ -77,11 +77,11 @@
poweron__poweron__ustt_timeout, \
poweron__poweron__btt_timeout, \
poweron__poweron__beacon, \
- poweron__poweron_joining__unassociated, \
+ poweron__poweron_joining__left, \
poweron__usta__ustt_timeout, \
poweron__usta__beacon, \
poweron__usta__usta_ind, \
- poweron__usta_joining__unassociated, \
+ poweron__usta_joining__left, \
poweron__sta__enter, \
poweron__sta__beacon, \
poweron__sta__beacon_not_received, \
@@ -149,7 +149,7 @@ __m (drv__stopped__drv_sta_set_avln_hfid_req)
__m (drv__stopped__drv_sta_set_tonemask_req)
__m (drv__stopped__drv_sta_mac_start_req)
__m (drv__started__drv_sta_mac_stop_req)
-__0 (drv__stopping__unassoc)
+__0 (drv__stopping__left)
__m (process_cc_set_tei_map_ind)
__m (process_cm_unassociated_sta_ind)
@@ -168,11 +168,11 @@ __0 (poweron_start)
__0 (poweron__poweron__ustt_timeout)
__0 (poweron__poweron__btt_timeout)
__n (poweron__poweron__beacon, cp_net_t *net, cp_sta_t *sta)
-__0 (poweron__poweron_joining__unassociated)
+__0 (poweron__poweron_joining__left)
__0 (poweron__usta__ustt_timeout)
__n (poweron__usta__beacon, cp_net_t *net, cp_sta_t *sta)
__n (poweron__usta__usta_ind, cp_net_t *net, cp_sta_t *sta)
-__0 (poweron__usta_joining__unassociated)
+__0 (poweron__usta_joining__left)
__0 (poweron__sta__enter)
__n (poweron__sta__beacon, cp_net_t *net, cp_sta_t *sta)
__0 (poweron__sta__beacon_not_received)
diff --git a/cesar/cp2/sta/action/test/utest/src/poweron.c b/cesar/cp2/sta/action/test/utest/src/poweron.c
index f5a478c564..2a27d66132 100644
--- a/cesar/cp2/sta/action/test/utest/src/poweron.c
+++ b/cesar/cp2/sta/action/test/utest/src/poweron.c
@@ -290,9 +290,9 @@ poweron_test_cases (test_t t)
{
scenario_entry_t entries[] = {
/* POWERON. */
- SCENARIO_ACTION (poweron__poweron_joining__unassociated),
+ SCENARIO_ACTION (poweron__poweron_joining__left),
/* USTA. */
- SCENARIO_ACTION (poweron__usta_joining__unassociated),
+ SCENARIO_ACTION (poweron__usta_joining__left),
SCENARIO_END
};
scenario_run (t, entries, &globals);
diff --git a/cesar/cp2/sta/action/test/utest/src/scenario_actions.c b/cesar/cp2/sta/action/test/utest/src/scenario_actions.c
index 5250fe9cba..93697d530c 100644
--- a/cesar/cp2/sta/action/test/utest/src/scenario_actions.c
+++ b/cesar/cp2/sta/action/test/utest/src/scenario_actions.c
@@ -82,7 +82,7 @@ __m (drv__stopped__drv_sta_set_avln_hfid_req)
__m (drv__stopped__drv_sta_set_tonemask_req)
__m (drv__stopped__drv_sta_mac_start_req)
__m (drv__started__drv_sta_mac_stop_req)
-__0 (drv__stopping__unassoc)
+__0 (drv__stopping__left)
__m (process_cc_set_tei_map_ind)
__m (process_cm_unassociated_sta_ind)
@@ -103,7 +103,7 @@ __0 (poweron__poweron__btt_timeout)
__n (poweron__poweron__beacon,
(cp_net_t *, net),
(cp_sta_t *, sta))
-__0 (poweron__poweron_joining__unassociated)
+__0 (poweron__poweron_joining__left)
__0 (poweron__usta__ustt_timeout)
__n (poweron__usta__beacon,
(cp_net_t *, net),
@@ -111,7 +111,7 @@ __n (poweron__usta__beacon,
__n (poweron__usta__usta_ind,
(cp_net_t *, net),
(cp_sta_t *, sta))
-__0 (poweron__usta_joining__unassociated)
+__0 (poweron__usta_joining__left)
__0 (poweron__sta__enter)
__n (poweron__sta__beacon,
(cp_net_t *, net),
diff --git a/cesar/cp2/sta/action/drv.h b/cesar/cp2/sta/action/drv.h
index 1bb1bf87d1..0c044fd400 100644
--- a/cesar/cp2/sta/action/drv.h
+++ b/cesar/cp2/sta/action/drv.h
@@ -174,14 +174,14 @@ cp_sta_action_drv__started__drv_sta_mac_stop_req (cp_t *ctx,
cp_mme_rx_t *mme);
/**
* Handle STOPPING => UNASSOC.
* \param ctx control plane context
*
* Now that we are unassociated, cleanup everything and send a
* DRV_STA_MAC_STOP.CNF.
*/
void
-cp_sta_action_drv__stopping__unassoc (cp_t *ctx);
+cp_sta_action_drv__stopping__left (cp_t *ctx);
END_DECLS
@@ -174,14 +174,14 @@ cp_sta_action_drv__started__drv_sta_mac_stop_req (cp_t *ctx,
cp_mme_rx_t *mme);
/**
- * Handle STOPPING => UNASSOC.
+ * Handle STOPPING => LEFT.
* \param ctx control plane context
*